Class: Command::Runner::Backends::UnsafeFake
- Defined in:
- lib/command/runner/backends/unsafe_fake.rb
Class Method Summary collapse
-
.unsafe? ⇒ Boolean
A backend is considered unsafe when the arguments are exposed directly to the shell.
Methods inherited from Fake
available?, #call, #initialize, #ran?, #unsafe?, unsafe_execution?
Constructor Details
This class inherits a constructor from Command::Runner::Backends::Fake
Class Method Details
.unsafe? ⇒ Boolean
A backend is considered unsafe when the arguments are exposed directly to the shell. This is a vulnerability, so we mark the class as unsafe and when we’re about to pass the arguments to the backend, escape the safe interpolations.
13 14 15 |
# File 'lib/command/runner/backends/unsafe_fake.rb', line 13 def self.unsafe? true end |